@@ -583,7 +583,7 @@ class Install(MethodsInterface):
         install_admin.clear()
         for k,v in self.clVars.select('install.cl_migrate_user',
                                       'install.cl_migrate_admin',
-                                      install_cl_migrate_admin__ne="none"):
+                                      install_cl_migrate_admin__ne=""):
             install_admin[k] = v
             install_admin.save()
         return True
