@@ -358,14 +358,14 @@ class VariableClMigrateAdmin(UserHelper, Variable):
     Migrate users list
     """
     type = 'choice-list'
-    default_value = "none"
+    default_value = ""
 
     def init(self):
         self.label = _("Administrator")
 
     def choice(self):
         return [
-            ("none", ""),
+            ("", ""),
             ("all", _("Full access")),
             ("update", _("System update")),
         ]
@@ -379,7 +379,7 @@ class VariableClMigrateAdmin(UserHelper, Variable):
                 for x in self.Get('cl_migrate_user')]
 
     def set(self, value):
-        name_map = {'update':'system_update'}
+        name_map = {'update':'system_update', 'none':''}
         value = map(lambda x:name_map.get(x,x), value)
         return map(lambda x: x if x else self.default_value, value)
 
